@@ -1,5 +1,6 @@
-// Copyright (c) 2001-2003 Rob Kaper <cap@capsi.com>,
-//               2001 Erik Bourget <ebourg@cs.mcgill.ca>
+// Copyright © 2001-2003 Rob Kaper <cap@capsi.com>,
+//             2001 Erik Bourget <ebourg@cs.mcgill.ca>
+//             2010-2015 Sylvain Rochet <gradator@gradator.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -11,9 +12,8 @@
 // General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// along with this program; see the file COPYING. If not, see
+// <http://www.gnu.org/licenses/>.
 
 #ifndef MONOP_AUCTION_H
 #define MONOP_AUCTION_H
@@ -26,7 +26,7 @@ class Player;
 class Auction : public GameObject
 {
  public:
- 	enum Status { Bidding = 0, GoingOnce = 1, GoingTwice = 2, Sold = 3, PaymentDue = 4, Completed = 5 };
+	enum Status { Bidding = 0, GoingOnce = 1, GoingTwice = 2, Sold = 3 };
 
 	Auction();
 	void setEstate(Estate *estate) { m_estate = estate; }
