@@ -20,6 +20,7 @@
 
 #include <vector>
 #include <string>
+#include <random>
 
 #include "gameobject.h"
 #include "display.h"
@@ -41,6 +42,8 @@ class Game : public GameObject
 
 		enum Status { Config, Init, Run, End };
 
+		std::default_random_engine m_randomEngine;
+
 		void ioWrite(const char *data, ...);
 		void ioWrite(const std::string data);
 		void ioInfo(const char *data, ...);
