@@ -49,14 +49,12 @@ protected:
 	 */
 	int addListenPort(const int port);
 	int addListenFd(const int fd);
-	virtual void socketHandler( Socket *socket, const std::string &data = "" );
 
 private:
 	/*
 	 * May return 0 in case the accept failed.
 	 */
 	Socket *acceptSocket(int fd);
-	void delSocket(Socket *socket);
 
 	fd_set m_readfdset;
 	fd_set m_writefdset;
