@@ -31,7 +31,7 @@
 class Socket
 {
 public:
-	enum Status { Connect, ConnectFailed, New, Ok, Close };
+	enum Status { Connect, Ok, Close };
 	enum Type { Player, Metaserver };
 
 	Socket(int fd);
